import { R as ResolvedConfig, F as File, T as TaskResultPack, S as SnapshotResult, a as TestFactory, b as SuiteCollector, c as TestFunction, d as SuiteHooks, U as UserOptions } from './options-63a726fa';
export { u as Arrayable, A as Awaitable, C as CliOptions, g as ComputeMode, v as Environment, E as EnvironmentReturn, F as File, G as GlobalContext, H as HookListener, M as ModuleCache, N as Nullable, n as Reporter, R as ResolvedConfig, e as RunMode, o as SnapshotData, r as SnapshotMatchOptions, S as SnapshotResult, q as SnapshotStateOptions, t as SnapshotSummary, p as SnapshotUpdateState, j as Suite, b as SuiteCollector, d as SuiteHooks, l as Task, h as TaskBase, i as TaskResult, T as TaskResultPack, f as TaskState, k as Test, m as TestCollector, a as TestFactory, c as TestFunction, s as UncheckedSnapshot, U as UserOptions, V as VitestContext } from './options-63a726fa';
import { MessagePort } from 'worker_threads';
import { TransformResult } from 'vite';
export { assert, default as chai, expect, should } from 'chai';
import sinon from 'sinon';
export { default as sinon } from 'sinon';
import 'pretty-format';

interface WorkerContext {
    port: MessagePort;
    config: ResolvedConfig;
    files: string[];
    invalidates?: string[];
}
interface RpcMap {
    workerReady: [[], void];
    fetch: [[id: string], TransformResult | null | undefined];
    onCollected: [[files: File[]], void];
    onFinished: [[], void];
    onTaskUpdate: [[pack: TaskResultPack], void];
    onWatcherStart: [[], void];
    onWatcherRerun: [[files: string[], trigger: string], void];
    snapshotSaved: [[snapshot: SnapshotResult], void];
}
declare type RpcCall = <T extends keyof RpcMap>(method: T, ...args: RpcMap[T][0]) => Promise<RpcMap[T][1]>;
declare type RpcSend = <T extends keyof RpcMap>(method: T, ...args: RpcMap[T][0]) => void;
declare type RpcPayload<T extends keyof RpcMap = keyof RpcMap> = {
    id: string;
    method: T;
    args: RpcMap[T][0];
};

declare const suite: {
    (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
    concurrent: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        skip(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        only(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        todo(suiteName: string): SuiteCollector;
    };
    skip: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    only: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    todo: {
        (suiteName: string): SuiteCollector;
        concurrent: (suiteName: string) => SuiteCollector;
    };
};
declare const defaultSuite: SuiteCollector;
declare function createSuiteHooks(): {
    beforeAll: never[];
    afterAll: never[];
    beforeEach: never[];
    afterEach: never[];
};
declare const test: {
    (name: string, fn: TestFunction, timeout?: number | undefined): void;
    concurrent: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        skip(name: string, fn: TestFunction, timeout?: number | undefined): void;
        only(name: string, fn: TestFunction, timeout?: number | undefined): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    only: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare const describe: {
    (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
    concurrent: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        skip(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        only(suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        todo(suiteName: string): SuiteCollector;
    };
    skip: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    only: {
        (suiteName: string, factory?: TestFactory | undefined): SuiteCollector;
        concurrent: (suiteName: string, factory?: TestFactory | undefined) => SuiteCollector;
    };
    todo: {
        (suiteName: string): SuiteCollector;
        concurrent: (suiteName: string) => SuiteCollector;
    };
};
declare const it: {
    (name: string, fn: TestFunction, timeout?: number | undefined): void;
    concurrent: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        skip(name: string, fn: TestFunction, timeout?: number | undefined): void;
        only(name: string, fn: TestFunction, timeout?: number | undefined): void;
        todo(name: string): void;
    };
    skip: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    only: {
        (name: string, fn: TestFunction, timeout?: number | undefined): void;
        concurrent(name: string, fn: TestFunction, timeout?: number | undefined): void;
    };
    todo: {
        (name: string): void;
        concurrent(name: string): void;
    };
};
declare const beforeAll: (fn: SuiteHooks['beforeAll'][0], timeout?: number | undefined) => void;
declare const afterAll: (fn: SuiteHooks['afterAll'][0], timeout?: number | undefined) => void;
declare const beforeEach: (fn: SuiteHooks['beforeEach'][0], timeout?: number | undefined) => void;
declare const afterEach: (fn: SuiteHooks['afterEach'][0], timeout?: number | undefined) => void;
declare function clearContext(): void;

declare const mock: sinon.SinonMockStatic;
declare const spy: sinon.SinonSpyStatic;
declare const stub: sinon.SinonStubStatic;

declare module 'vite' {
    interface UserConfig {
        /**
         * Options for Vitest
         */
        test?: UserOptions;
    }
}
declare global {
    namespace Chai {
        interface Assertion {
            toMatchSnapshot(message?: string): Assertion;
            matchSnapshot(message?: string): Assertion;
            toEqual(expected: any): void;
            toStrictEqual(expected: any): void;
            toBe(expected: any): void;
            toMatch(expected: string | RegExp): void;
            toMatchObject(expected: any): void;
            toContain(item: any): void;
            toContainEqual(item: any): void;
            toBeTruthy(): void;
            toBeFalsy(): void;
            toBeGreaterThan(num: number): void;
            toBeGreaterThanOrEqual(num: number): void;
            toBeLessThan(num: number): void;
            toBeLessThanOrEqual(num: number): void;
            toBeNaN(): void;
            toBeUndefined(): void;
            toBeNull(): void;
            toBeDefined(): void;
            toBeInstanceOf(c: any): void;
            toBeCalledTimes(n: number): void;
            toHaveLength(l: number): void;
            toBeCloseTo(number: number, numDigits?: number): void;
            toHaveBeenCalledTimes(n: number): void;
            toHaveBeenCalledOnce(): void;
            toHaveBeenCalled(): void;
            toBeCalled(): void;
            toHaveBeenCalledWith(...args: any[]): void;
            toBeCalledWith(...args: any[]): void;
            toHaveBeenNthCalledWith(n: number, ...args: any[]): void;
            nthCalledWith(n: number, ...args: any[]): void;
            toHaveBeenLastCalledWith(...args: any[]): void;
            lastCalledWith(...args: any[]): void;
            toThrow(expected?: string | RegExp): void;
            toThrowError(expected?: string | RegExp): void;
            toReturn(): void;
            toHaveReturned(): void;
            toReturnTimes(times: number): void;
            toHaveReturnedTimes(times: number): void;
            toReturnWith(value: any): void;
            toHaveReturnedWith(value: any): void;
            toHaveLastReturnedWith(value: any): void;
            lastReturnedWith(value: any): void;
            toHaveNthReturnedWith(nthCall: number, value: any): void;
            nthReturnedWith(nthCall: number, value: any): void;
        }
    }
}

export { RpcCall, RpcMap, RpcPayload, RpcSend, WorkerContext, afterAll, afterEach, beforeAll, beforeEach, clearContext, createSuiteHooks, defaultSuite, describe, it, mock, spy, stub, suite, test };
